@@ -189,6 +189,8 @@ class Experimento:
         self.matriz_recurrencia_region_cuadriculada = None
         self.matriz_cuadriculada = None
         self.matriz_cuadriculada_regiones_preferidas = None
+        self.matriz_cuadriculada_solo_regiones_preferidas
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = None
 
         self.visitas_regiones_preferidas = None
         self.visitas_regiones_no_preferidas = None
@@ -472,6 +474,38 @@ class Experimento:
         self.matriz_cuadriculada_regiones_preferidas = \
             np.reshape(arreglo_regiones_preferidas, (self.cantidad_filas, self.cantidad_columnas))
 
+        self.matriz_cuadriculada_regiones_preferidas = np.flipud(self.matriz_cuadriculada_regiones_preferidas)
+
+    def genera_matriz_cuadriculada_solo_regiones_preferidas(self):
+        matriz_cuadriculada_plana = np.flipud(self.matriz_cuadriculada).flatten()
+        self.visitas_regiones_preferidas = matriz_cuadriculada_plana[self.regiones_preferidas]
+
+        resultado_visitas_regiones_preferidas = sum(self.visitas_regiones_preferidas)
+
+        arreglo_regiones_preferidas = np.zeros(len(matriz_cuadriculada_plana))
+        arreglo_regiones_preferidas[self.regiones_preferidas] = resultado_visitas_regiones_preferidas
+
+        self.matriz_cuadriculada_solo_regiones_preferidas = \
+            np.reshape(arreglo_regiones_preferidas, (self.cantidad_filas, self.cantidad_columnas))
+
+        self.matriz_cuadriculada_solo_regiones_preferidas = np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
+
+
+    def genera_matriz_cuadriculada_solo_regiones_no_preferidas(self):
+        matriz_cuadriculada_plana = np.flipud(self.matriz_cuadriculada).flatten()
+        self.visitas_regiones_preferidas = matriz_cuadriculada_plana[self.regiones_preferidas]
+        self.visitas_regiones_no_preferidas = np.delete(matriz_cuadriculada_plana, self.regiones_preferidas)
+
+        resultado_visitas_regiones_no_preferidas = sum(self.visitas_regiones_no_preferidas)
+
+        arreglo_regiones_no_preferidas = resultado_visitas_regiones_no_preferidas * np.ones(len(matriz_cuadriculada_plana))
+        arreglo_regiones_no_preferidas[self.regiones_preferidas] = 0
+
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+            np.reshape(arreglo_regiones_no_preferidas, (self.cantidad_filas, self.cantidad_columnas))
+
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
+
     def calcula_matrices_de_recurrencia(self):
 
         self.obtener_indice_regiones_objeto()
@@ -1433,6 +1467,174 @@ class Experimento:
 
             ax.view_init(azim=rot_grafica_3d)
 
+        elif grafica == 'region_cuadricula_3d_solo_regiones_preferidas':
+
+            print("Entro a regionCuadricula3d, solo regiones preferidas")
+
+            rot_grafica_3d = rotacion_grafica_3d
+
+            objeto_1_x = self.objeto_relevante_1[0]
+            objeto_1_y = self.objeto_relevante_1[1]
+
+            objeto_2_x = self.objeto_relevante_2[0]
+            objeto_2_y = self.objeto_relevante_2[1]
+
+            objeto_3_x = self.objeto_relevante_3[0]
+            objeto_3_y = self.objeto_relevante_3[1]
+
+            objeto_4_x = self.objeto_relevante_4[0]
+            objeto_4_y = self.objeto_relevante_4[1]
+
+            if getattr(sys, 'frozen', False):
+                os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
+
+            data_array = np.array(np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas))
+
+            print(data_array)
+
+            ax = fig.add_subplot(111, projection='3d')
+
+            ax.view_init(azim=rot_grafica_3d % 360, elev=0)
+
+            x_data, y_data = np.meshgrid(np.arange(data_array.shape[1]),
+                                         np.arange(data_array.shape[0]))
+
+            x_data = x_data.flatten()
+            y_data = y_data.flatten()
+            z_data = data_array.flatten()
+
+            tamanio_horizontal = self.dimension_caja[0] / self.cantidad_columnas
+            tamanio_vertical = self.dimension_caja[1] / self.cantidad_filas
+
+            objeto_1_x_pos_matriz_cuadriculada = int(objeto_1_x // tamanio_horizontal)
+            objeto_1_y_pos_matriz_cuadriculada = int(objeto_1_y // tamanio_vertical)
+
+            objeto_2_x_pos_matriz_cuadriculada = int(objeto_2_x // tamanio_horizontal)
+            objeto_2_y_pos_matriz_cuadriculada = int(objeto_2_y // tamanio_vertical)
+
+            objeto_3_x_pos_matriz_cuadriculada = int(objeto_3_x // tamanio_horizontal)
+            objeto_3_y_pos_matriz_cuadriculada = int(objeto_3_y // tamanio_vertical)
+
+            objeto_4_x_pos_matriz_cuadriculada = int(objeto_4_x // tamanio_horizontal)
+            objeto_4_y_pos_matriz_cuadriculada = int(objeto_4_y // tamanio_vertical)
+
+            print([objeto_1_x_pos_matriz_cuadriculada],
+                  [objeto_2_x_pos_matriz_cuadriculada],
+                  [objeto_3_x_pos_matriz_cuadriculada],
+                  [objeto_4_x_pos_matriz_cuadriculada])
+            print([objeto_1_y_pos_matriz_cuadriculada],
+                  [objeto_2_y_pos_matriz_cuadriculada],
+                  [objeto_3_y_pos_matriz_cuadriculada],
+                  [objeto_4_y_pos_matriz_cuadriculada])
+
+            ax.bar3d(x_data,
+                     y_data,
+                     np.zeros(len(z_data)),
+                     1, 1, z_data)
+
+            if 0 < rot_grafica_3d <= 90:
+                ax.xaxis._axinfo['juggled'] = (0, 0, 0)
+                ax.yaxis._axinfo['juggled'] = (1, 1, 1)
+                ax.zaxis._axinfo['juggled'] = (2, 2, 2)
+            elif 90 < rot_grafica_3d <= 180:
+                ax.xaxis._axinfo['juggled'] = (0, 0, 0)
+                ax.yaxis._axinfo['juggled'] = (0, 1, 2)
+                ax.zaxis._axinfo['juggled'] = (0, 2, 1)
+            elif 180 < rot_grafica_3d <= 270:
+                ax.xaxis._axinfo['juggled'] = (1, 0, 2)
+                ax.yaxis._axinfo['juggled'] = (0, 1, 2)
+                ax.zaxis._axinfo['juggled'] = (2, 2, 2)
+            elif 270 < rot_grafica_3d <= 360:
+                ax.xaxis._axinfo['juggled'] = (1, 0, 2)
+                ax.yaxis._axinfo['juggled'] = (1, 1, 1)
+                ax.zaxis._axinfo['juggled'] = (1, 2, 0)
+
+            ax.view_init(azim=rot_grafica_3d)
+
+        elif grafica == 'region_cuadricula_3d_solo_regiones_no_preferidas':
+
+            print("Entro a regionCuadricula3d, solo regiones preferidas")
+
+            rot_grafica_3d = rotacion_grafica_3d
+
+            objeto_1_x = self.objeto_relevante_1[0]
+            objeto_1_y = self.objeto_relevante_1[1]
+
+            objeto_2_x = self.objeto_relevante_2[0]
+            objeto_2_y = self.objeto_relevante_2[1]
+
+            objeto_3_x = self.objeto_relevante_3[0]
+            objeto_3_y = self.objeto_relevante_3[1]
+
+            objeto_4_x = self.objeto_relevante_4[0]
+            objeto_4_y = self.objeto_relevante_4[1]
+
+            if getattr(sys, 'frozen', False):
+                os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
+
+            data_array = np.array(np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas))
+
+            print(data_array)
+
+            ax = fig.add_subplot(111, projection='3d')
+
+            ax.view_init(azim=rot_grafica_3d % 360, elev=0)
+
+            x_data, y_data = np.meshgrid(np.arange(data_array.shape[1]),
+                                         np.arange(data_array.shape[0]))
+
+            x_data = x_data.flatten()
+            y_data = y_data.flatten()
+            z_data = data_array.flatten()
+
+            tamanio_horizontal = self.dimension_caja[0] / self.cantidad_columnas
+            tamanio_vertical = self.dimension_caja[1] / self.cantidad_filas
+
+            objeto_1_x_pos_matriz_cuadriculada = int(objeto_1_x // tamanio_horizontal)
+            objeto_1_y_pos_matriz_cuadriculada = int(objeto_1_y // tamanio_vertical)
+
+            objeto_2_x_pos_matriz_cuadriculada = int(objeto_2_x // tamanio_horizontal)
+            objeto_2_y_pos_matriz_cuadriculada = int(objeto_2_y // tamanio_vertical)
+
+            objeto_3_x_pos_matriz_cuadriculada = int(objeto_3_x // tamanio_horizontal)
+            objeto_3_y_pos_matriz_cuadriculada = int(objeto_3_y // tamanio_vertical)
+
+            objeto_4_x_pos_matriz_cuadriculada = int(objeto_4_x // tamanio_horizontal)
+            objeto_4_y_pos_matriz_cuadriculada = int(objeto_4_y // tamanio_vertical)
+
+            print([objeto_1_x_pos_matriz_cuadriculada],
+                  [objeto_2_x_pos_matriz_cuadriculada],
+                  [objeto_3_x_pos_matriz_cuadriculada],
+                  [objeto_4_x_pos_matriz_cuadriculada])
+            print([objeto_1_y_pos_matriz_cuadriculada],
+                  [objeto_2_y_pos_matriz_cuadriculada],
+                  [objeto_3_y_pos_matriz_cuadriculada],
+                  [objeto_4_y_pos_matriz_cuadriculada])
+
+            ax.bar3d(x_data,
+                     y_data,
+                     np.zeros(len(z_data)),
+                     1, 1, z_data)
+
+            if 0 < rot_grafica_3d <= 90:
+                ax.xaxis._axinfo['juggled'] = (0, 0, 0)
+                ax.yaxis._axinfo['juggled'] = (1, 1, 1)
+                ax.zaxis._axinfo['juggled'] = (2, 2, 2)
+            elif 90 < rot_grafica_3d <= 180:
+                ax.xaxis._axinfo['juggled'] = (0, 0, 0)
+                ax.yaxis._axinfo['juggled'] = (0, 1, 2)
+                ax.zaxis._axinfo['juggled'] = (0, 2, 1)
+            elif 180 < rot_grafica_3d <= 270:
+                ax.xaxis._axinfo['juggled'] = (1, 0, 2)
+                ax.yaxis._axinfo['juggled'] = (0, 1, 2)
+                ax.zaxis._axinfo['juggled'] = (2, 2, 2)
+            elif 270 < rot_grafica_3d <= 360:
+                ax.xaxis._axinfo['juggled'] = (1, 0, 2)
+                ax.yaxis._axinfo['juggled'] = (1, 1, 1)
+                ax.zaxis._axinfo['juggled'] = (1, 2, 0)
+
+            ax.view_init(azim=rot_grafica_3d)
+
         return fig
 
 
